@@ -18,9 +18,7 @@ def ensure_config_loaded():
             raise Exception("Could not configure kubernetes python client")
 
     proxy_url = os.getenv('HTTPS_PROXY', os.getenv('HTTP_PROXY', None))
-    k8s_proxy_bypass = os.getenv('K8S_PROXY_BYPASS')
-
-    if proxy_url and k8s_proxy_bypass != "true":
+    if proxy_url and not app_config['K8S_PROXY_BYPASS']:
         logger.info(f"Setting proxy: {proxy_url}")
         client.Configuration._default.proxy = proxy_url
 
